@@ -3,7 +3,6 @@ package Provision::Unix::Utility;
 use strict;
 use warnings;
 
-use lib "inc";
 use lib "lib";
 
 use Cwd;
@@ -37,6 +36,7 @@ sub new {
     return $self;
 }
 
+
 =for TODO
 
 Go through this file and replace all the instances of carp and croak with calls
@@ -342,7 +342,7 @@ sub chown {
 
     if ( $p{gid} =~ /\A[0-9\-]+\z/ ) {
         $ngid = int( $p{gid} );
-        prov->audit( "using $ngid from int($p{gid})" );
+        $prov->audit( "using $ngid from int($p{gid})" );
     }
     else {
         $ngid = getgrnam( $p{gid} );
